# Science Gothic

Science Gothic™ is a libre sans serif variable font commissioned by Google Fonts. Its wide design range allows it to take on many different looks and uses, striking or classy, from superheroes and detectives to cosmetics to business and technology.

The underlying design is based closely on Morris Fuller Benton’s Bank Gothic (1930–34) all-caps typeface for American Type Founders. However, Science Gothic adds a lowercase, extensive language coverage, and four design axes: extreme weight and width (much greater more the original), plus contrast and slant. Science Gothic is a team effort, by Thomas Phinney, Vassil Kateliev and Brandon Buerkle. Special thanks to Igor Freiberger for his early contributions.

This repo is where development and updates to this project can be found. Source files are in multiple formats: FontLab VFJ (vector font JSON) format, FontLab VFC (binary) format. Generated versions include UFO source files, and variable TTF end-user fonts. Occasionally we previously generated fonts corresponding to masters and instances, but these have not been not maintained going forward.

(Particularly major updates are described below, but not every update.)

## License

Science Gothic is licensed under the SIL Open Font License v1.1. This is a libre free software license. Please [refer to the license](./OFL.txt) for details.

# Variable Axes

Science Gothic has the following axes:

| Axis       | Tag    | Range        | Default | Description                                                                |
| ---------- | ------ | ------------ | ------- | -------------------------------------------------------------------------- |
| Slant      | `slnt` | 0 to -10     | 0       | Upright (0°) to Oblique (about 10°)                                        |
| Weight     | `wght` | 100 to 900   | 400     | Thin to Black. Can be defined with the CSS font-weight property.           |
| Width      | `wdth` | 50 to 200    | 100     | UltraCondensed to ExtraExpanded. Can be defined with CSS font-width.       |
| Contrast   | `CNTR` | 0 to 75      | 0       | No visible contrast (0) to Maximum Contrast (75% reduction of thin stroke) |

### Axis Definitions

- **Slant** `slnt` – 0 to -10. The rightward angle of letters, roughly equivalent to italic. Note: `-10` (negative 15) corresponds to a 10° clockwise slant, about the same as a typical italic. Going to `-5` or more will activate alternate shapes for “a” and “f”, converting to a “single story” `a` and an `f` with a descending stroke. Use Slant for secondary emphasis in text, or for effect in display. In text, it can be useful to use the full slant for italic/emphasis, while at display sizes, you might choose an intermediate value for effect.

- **Weight** `wght` - 100 to 900. The thickness of letter strokes and how dark the text looks overall. More extreme values (100–250 and 750–900) are best saved for larger sizes. If using Science Gothic for body text, we suggest a weight not too far from 400 (say 340–450). Differences in weight can provide emphasis in text, show user interaction, or adjust the tone of communication. For light text on dark backgrounds, 400 (“Regular”) tends to be appropriate for text and code. For dark text on a light background, it can be beneficial to adjust the weight upwards to 500 (“Medium”).

- **Width** `wdth` – 50 to 200. The default 100 width is based on the default width of Bank Gothic, which is arguably just a little wide, so a slightly narrower width (85–95) may often be desirable, especially for multi-sentence or body text. The most extreme widths, especially the wider ones, are **very** extreme, and to be used sparingly for effect and typically at very large sizes.

- **Contrast** `CNTR` - 0 to 75. The default 0 contrast is based on Bank Gothic, and has no visible contrast. For multi-sentence text and/or body text sizes, even a little contrast (5–15) can make the text more comfortable.


# Language Support

Science Gothic covers the GF Latin Plus, Latin Expert, and Cyrillic Plus character sets, including small caps. This is similar to Adobe Latin 4 and Adobe Adobe Cyrillic 2.

<details>
<summary><b><!-------->⚙️ The specific list of languages supported is:<!--------></b> (Click to expand)</summary>

Abaza Abenaki Abkhaz Adyghe Afaan Oromo Afrikaans Agu Akhvakh Albanian Alsatian Altay Amis Andi Anutu Aragonese Aranese Archi Aromanian Arrernte Arvanitic (Latin) Asturian Atayal Asu Avar Aymara Azerbaijani Azerbaijani/Azeri (Cyrillic) Bagvalal Balkar Bashkir Basque Belarusian Bemba Bena Bikol Bislama Bosnian Botlikh Breton Budukh Bulgarian Buryat Catalan Cebuanu Chamalal Chamorro Chavacano Chechen Chichewa Chickasaw Chiga Chukchi Chuvash Cimbrian Cofán Cornish Corsican Creek Crimean Tatar Croatian Czech Danish Dargwa/Dargin Dawan Delaware Dholuo Drehu Dungan Dutch Embu Enets English Erzya Eskimo Esperanto Estonian Even Evenki Faroese Fijian Filipino Finnish Folkspraak French Frisian Friulian Gagauz Galician Ganda Genoese German Gikuyu Godoberi Gooniyandi Greenlandic (Kalaallisut) Guadeloupean Creole Gwich’in Gusii Haitian Creole Hän Hawaiian Hiligaynon Hinukh Hopi Hotcąk (Latin) Hungarian Hunzib Icelandic Ido Igbo Ilocano Indonesian Ingush Interglossa Interlingua Irish Istro‑Romanian Italian Itelmen Jamaican Javanese (Latin) Jèrriais Jola‑Fonyi Juhuri/çuhuri (Cyrillic) Kabardian Kabuverdianu (Cape Verdean Creole) Kaingang Kala Lagaw Ya Kalaallisut Kalenjin Kalmyk Kamba Kapampangan (Latin) Kaqchikel Karachay Karaim (Cyrillic) Karakalpak Karata Karelian (Latin) Kazakh Kashubian Ket (Cyrillic) Khakas (Cyrillic) Khanty Khinalugh Kildin Sami Kikongo Kinyarwanda Kiribati Kirundi Klingon (Latin) Komi Koryak Krymchak Kryts Kubachi Kumyk Kurdish Kyrgyz Ladin Lak Latin Latino sine Flexione Latvian Lezgian Lingua Franca Nova (Cyrillic) Lithuanian Lojban Lombard Low Saxon Luo Luyia Luxembourgish Maasai Macedonian Machame Makhuwa Makonde Malagasy Malay Maltese Mansi Manx Māori Mari (Hill and Meadow) Marquesan Megleno‑Romanian Meriam Mir Meru Mirandese Mohawk Moksha Moldovan Mongolian Montagnais Montenegrin Morisyen Murrinh‑Patha Nagamese Creole Nahuatl Nanai Ndebele Neapolitan Nenets Nganasan Ngiyambaa Nogai Niuean Noongar Norwegian Novial Nyankole Occidental Occitan Old Icelandic Old Norse Onĕipŏt Oroch Orok Oromo Oshiwambo Ossetian Palauan Papiamento Piedmontese Polish Portuguese Potawatomi Q’eqchi’ Quechua Rarotongan Romanian Romansh Rombo Rotokas Rundi Russian Rusyn Rutul Rwa Sakha/Yakut Sami (Inari Sami) Sami (Lule Sami) Sami (Northern Sami) Sami (Southern Sami) Samburu Samoan Sango Saramaccan Sardinian Scottish Gaelic Sena Serbian Seri Seychellois Creole Shambala Shawnee Shona Shor Sicilian Silesian Slovak Slovenian Slovio Soga Somali Sorbian (Lower Sorbian) Sorbian (Upper Sorbian) Sotho (Northern) Sotho (Southern) Spanish Sranan Sundanese (Latin) Swahili Swazi Swedish Tabassaran Tagalog Tahitian Tajik Talysh (Cyrillic) Tat Tatar Tati Teso Tetum Tindi Tofa Tok Pisin Tokelauan Tongan Tsakhur (Cyrillic) Tsez Tshiluba Tsonga Tswana Tumbuka Turkish Turkmen Tuvaluan Tuvan/Tuvinian Tzotzil Udi Udmurt Ukrainian Ulch Urum Uyghur (Cyrillic) Uzbek Venetian Vepsian Vietnamese Volapük Võro Votik (Cyrillic) Vunjo Wakhi (Cyrillic) Wallisian Walloon Waray‑Waray Warlpiri Wayuu Welsh Wik‑Mungkan West Polesian Wiradjuri Wolof Xavante Xhosa Yaghnobi (Cyrillic) Yapese Yindjibarndi Yukaghir (Northern and Southern) Yupik Zapotec Zarma Zazaki Zulu Zuni

</details>

# DOWNLOAD THE FONT
Get the latest working variable font here: https://github.com/googlefonts/science-gothic/tree/main/fonts/variable
Less flexible static fonts are here: https://github.com/googlefonts/science-gothic/tree/main/fonts/static/Instances

# Bugs
PLEASE report any BUGS OR ISSUES. You can file an issue right here in Github at: https://github.com/googlefonts/science-gothic/issues. Or just ask questions on social media, whatever. But feedback is welcome!

# Building Fonts
Our process for building fonts from our FontLab VFC/VFJ sources > UFO > FontMake > TTF (variable font) is [documented here](https://github.com/googlefonts/science-gothic/blob/master/documentation/compiling_fonts.md).


# Release Notes

## 

## 21 Dec 2022
- Ownership transferred to Google

## 14 Apr 2022
- most bugs quashed
- close to being release quality

## 19 March 2020
- Kerning is still in progress.
- Only a small handful of bugs left at this point.
- Just about done fixing all issues identified by FontBakery

## 17 November 2019

- Slant axis is enabled! Note the form change for /a and /f when they get more than half slanted. This has generated a fair number of bugs for some glyphs in their slanted versions, but nothing unmanageable. 
- Have started editing glyphs to tweak their shapes where slant does too much distortion of weight or stroke. Mainly diagonal strokes (think: A K N M R 2 4 7 & ?) and big curves (not many in this typeface, but they include: D 6 9)
- Kerning classes have all been created; kerning is well underway

## 1 November 2019

Primary design work was basically done. Just a few details here and there to fix. We are now entering the endgame! For the next three weeks or so, we will:

- create kerning classes and do kerning
- create the Slant axis, slanted glyphs, and add form change for just a very few (/a for certain, maybe /f)
- fix bugs and address any issues discovered

98.5% done glyph design work

## 14 October 2019

Made significant org/name changes to the former Contrast axis, now called “Y Opaque” ('YOPQ' axis tag). Instead of going from 0 – 100 (low to high) it goes from 18 to 124 (high to low contrast) representing the thickness of capital horizontal strokes, in thousandths of an em, at the default Medium weight. The default style is still low contrast, which is 124, at the “high” end of the horizontal stroke-thickness scale.

77% done glyph design work.

## 18 September 2019

Added UFO sources, and first variable TTF built from UFO + FontMake (with latest FontMake and Python) rather than from exporting from FontLab. Although FontLab VI uses UFO + FontMake internally for its variable font generation, it uses an older version of FontMake. The UFO + FontMake approach makes it easier for future development to be made with any UFO-compatible font editor. See https://github.com/googlefonts/science-gothic/issues/91 for details.

49% done glyph design work.

### 5 September 2019

Second variable font build. About 200 meaningful characters, including very nearly complete support for both English and Russian. 37% done glyph design work.

Around this time we had the last few contributions from Igor Freiberger. Thanks!

### 29 August 2019

Added first built variable font! Thought it was buggy, but turns out that is just Illustrator. Font is lovely in Axis-Praxis. https://recordit.co/g9KnZq2Dbv . Also added separate fonts for instances (ouch 104 fonts!). And the .designspace file. ~ 26% done glyph design work.

### 15 August 2019
16% done glyph design work.

### 10 August 2019

Added recipes to build auto layers.


### 8 August 2019

Added folder structure!

Masters folder:
- added variable font-in-progress in VFJ format (FontLab JSON text format)
- added Readme about formats etc.

### 7 August 2019

Added OFL.txt Open Font License and info

Added FontLab .enc encoding file

### 6 August 2019
Renamed the project to Science Gothic!

### 10 July 2019
Started the repo

## Who Is Behind This?

* Copyright holder: https://github.com/googlefonts/science-gothic/blob/master/AUTHORS.txt
* Contributors: https://github.com/googlefonts/science-gothic/blob/master/CONTRIBUTORS.txt

## License

Science Gothic fonts and their source files are licensed to others under the open source SIL Open Font License v1.1 (<http://scripts.sil.org/OFL>) with no Reserved Font Name. To view the specific terms and conditions please refer to [OFL.txt](https://github.com/googlefonts/science-gothic/OFL.txt)

Additional non-font source files are licensed to others under the Apache 2.0 open source license (<https://www.apache.org/licenses/LICENSE-2.0>).

## Language Coverage & Glyph Set

This typeface has extended Latin and extended Cyrillic, with over 1200 glyphs. [FontLab .enc encoding file](https://github.com/googlefonts/science-gothic/blob/master/Science%20Gothic.enc).
